@@ -121,4 +121,10 @@ class CreateImageCacheRequest(RpcRequest):
 		return self.get_query_params().get('RetentionDays')
 
 	def set_RetentionDays(self, RetentionDays):
-		self.add_query_param('RetentionDays', RetentionDays)
\ No newline at end of file
+		self.add_query_param('RetentionDays', RetentionDays)
+
+	def get_AutoMatchImageCache(self):
+		return self.get_query_params().get('AutoMatchImageCache')
+
+	def set_AutoMatchImageCache(self, AutoMatchImageCache):
+		self.add_query_param('AutoMatchImageCache', AutoMatchImageCache)
\ No newline at end of file
